@@ -394,7 +394,7 @@ class RedisRoot:
             save_consistency=False,
             economy=False
     ):
-        self.registered_models = {}
+        self.registered_models = []
         self.registered_django_models = {}
         if type(prefix) == str:
             self.prefix = prefix
@@ -413,7 +413,7 @@ class RedisRoot:
 
     @property
     def cached_models(self):
-        return list(set(self.registered_models.keys()))
+        return self.registered_models
 
     def _get_django_models_to_cache(self):
         django_models_to_cache = {}
@@ -432,15 +432,43 @@ class RedisRoot:
         django_models_to_cache = self._get_django_models_to_cache()
         for django_model, cache_conf in django_models_to_cache.items():
             cache_func = cache_conf['cache_func']
+            
+            def get_or_create_redis_model_from_django_model(django_model, redis_root):
+                registered_models_names = [model.__name__ for model in redis_root.registered_models]
+                redis_fields = django_fields_to_redis_fields(django_model, redis_root)
+                if django_model.__name__ in registered_models_names:
+                    existing_redis_model_index = redis_root.registered_models_names.index(django_model.__name__)
+                    existing_redis_model = redis_root.registered_models[existing_redis_model_index]
+                    new_redis_model = update_redis_model_from_redis_fields(existing_redis_model, redis_fields, redis_root)
+                else:
+                    new_redis_model = create_redis_model_from_redis_fields(redis_fields, redis_root)
+                return new_redis_model
+            
+            def django_fields_to_redis_fields(django_model, redis_root):
+                redis_fields = {}
+                for django_field in django_model._meta.get_fields():
+                    redis_field = django_field_to_redis_field(django_field, redis_root)
+                    if redis_field:
+                        django_field_name = django_field.name
+                        if django_field_name in ['id', 'pk']:
+                            django_field_name = 'django_id'
+                        redis_fields[django_field_name] = redis_field
+                return redis_fields
 
-            def django_field_to_redis_field(django_model, django_field, redis_root):
+            def create_redis_model_from_redis_fields(redis_fields, redis_root):
+                new_redis_model = type(django_model.__name__, (RedisModel,), redis_fields)
+                redis_root.register_models([new_redis_model])
+                return new_redis_model
 
-                def get_allowed_params(django_field, django_model, redis_root):
+            def django_field_to_redis_field(django_field, redis_root):
+
+                def get_allowed_params(django_field, redis_root):
                     allowed_params = ['null', 'default', 'choices', 'model']
                     allowed_redis_params = {}
                     for django_field_param_name in django_field.__dict__.keys():
                         if django_field_param_name in allowed_params:
                             value = getattr(django_field, django_field_param_name)
+                            print(django_field, django_field_param_name, value)
                             if django_field_param_name == 'choices':
                                 real_value = {}
                                 if value is not None:
@@ -450,8 +478,7 @@ class RedisRoot:
                                     real_value = None
                                 value = real_value
                             elif django_field_param_name == 'model':
-                                print(value)
-                                value = create_redis_model_from_django_model(value, redis_root)
+                                value = get_or_create_redis_model_from_django_model(value, redis_root)
                             allowed_redis_params[django_field_param_name] = value
                     return allowed_redis_params
 
@@ -491,26 +518,21 @@ class RedisRoot:
                         (redis_field,),
                         {}
                     )
-                    redis_field = redis_field_class(**get_allowed_params(django_field, django_model, redis_root))
-                return redis_field
-
-            def create_redis_model_from_django_model(django_model, redis_root):
-                redis_fields = {}
-                for django_field in django_model._meta.get_fields():
-                    redis_field = django_field_to_redis_field(django_model, django_field, redis_root)
-                    if redis_field:
-                        django_field_name = django_field.name
-                        if django_field_name in ['id', 'pk']:
-                            django_field_name = 'django_id'
-                        redis_fields[django_field_name] = redis_field
-
-                new_redis_model = type(django_model.__name__, (RedisModel,), redis_fields)
-
-                redis_root.register_models([new_redis_model])
-
+                    redis_field = redis_field_class(**get_allowed_params(django_field, redis_root))
+                return redis_field            
+            
+            def update_redis_model_from_redis_fields(existing_redis_model, redis_fields, redis_root):
+                new_redis_model = create_redis_model_from_redis_fields(redis_fields, redis_root)
+                new_registered_models = []
+                for redis_model in redis_root.registered_models:
+                    if redis_model == existing_redis_model:
+                        new_registered_models.append(new_redis_model)
+                    else:
+                        new_registered_models.append(redis_model)
+                redis_root.registered_models = new_registered_models
                 return new_redis_model
 
-            cache_func(django_model, self, create_redis_model_from_django_model)
+            cache_func(django_model, self, get_or_create_redis_model_from_django_model)
 
     def _get_connection_pool(self, connection_pool):
         if isinstance(connection_pool, redis.ConnectionPool):
@@ -538,7 +560,7 @@ class RedisRoot:
         for model in models_list:
             if issubclass(model, RedisModel):
                 if model not in self.registered_models:
-                    self.registered_models[model] = datetime.datetime.now()
+                    self.registered_models.append(model)
             else:
                 raise Exception(f'{model.__name__} class is not RedisModel')
 
